@@ -15,7 +15,7 @@ extends 'Zing::Watcher';
 
 use Zing::Kernel;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # ATTRIBUTES
 
@@ -751,6 +751,20 @@ This distribution provides watcher processes which to supervise child processes
 but also are capable of multitasking and performing other operations while
 monitoring supervised processes.
 
+=head2 virtual-actors
+
+  use Zing::Zang::Spawner;
+
+  my $zang = Zing::Zang::Spawner->new(
+    queues => ['schemes']
+  );
+
+  $zang->exercise;
+
+This distribution provides the ability to use virtual actors, which are
+processes (actors) created on-demand as a result of some system event. This
+feature is enabled by the L<Zing::Launcher> and L<Zing::Spawner> superclasses.
+
 =cut
 
 =head1 SEE ALSO
