@@ -12,11 +12,12 @@ use parent 'Data::Object::Cli';
 use Zing;
 use Zing::Channel;
 use Zing::Daemon;
+use Zing::Registry;
 
 use FlightRecorder;
 use File::Spec;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 our $name = 'zing <{command}> [<{app}>] [options]';
 
@@ -24,6 +25,7 @@ our $name = 'zing <{command}> [<{app}>] [options]';
 
 sub auto {
   {
+    clean => '_handle_clean',
     logs => '_handle_logs',
     pid => '_handle_pid',
     update => '_handle_update',
@@ -34,6 +36,7 @@ sub auto {
 
 sub subs {
   {
+    clean => 'Prune the processes registry',
     logs => 'Tap logs and output to STDOUT',
     pid => 'Display an application process ID',
     update => 'Hot-reload application processes',
@@ -49,8 +52,13 @@ sub spec {
       type => 'string',
       flag => 'a',
     },
+    process => {
+      desc => 'Reduce log output by process name',
+      type => 'string',
+      flag => 'p',
+    },
     level => {
-      desc => 'Restrict log output by log-level',
+      desc => 'Reduce log output by log-level',
       type => 'string',
       flag => 'l',
     },
@@ -65,9 +73,33 @@ sub spec {
       type => 'string',
       flag => 'd',
     },
+    tag => {
+      desc => 'Reduce log output by process tag',
+      type => 'string',
+      flag => 't',
+    },
+    verbose => {
+      desc => 'Produce verbose log output',
+      type => 'flag',
+      flag => 'v',
+    },
   }
 }
 
+sub _handle_clean {
+  my ($self) = @_;
+
+  my $r = Zing::Registry->new;
+
+  for my $id (@{$r->ids}) {
+    my $data = $r->store->recv($id) or next;
+    my $pid = $data->{process} or next;
+    $r->store->drop($id) unless kill 0, $pid;
+  }
+
+  $self->okay;
+}
+
 sub _handle_logs {
   my ($self) = @_;
 
@@ -78,14 +110,24 @@ sub _handle_logs {
 
     my $from = $info->{from};
     my $data = $info->{data};
+    my $logs = $data->{logs};
 
-    $data->{level} = $self->opts->level if $self->opts->level;
+    $logs->{level} = $self->opts->level if $self->opts->level;
 
-    my $logger = FlightRecorder->new($data);
+    my $logger = FlightRecorder->new($logs);
+    my $report = $self->opts->verbose ? 'verbose' : 'simple';
+    my $lines = $logger->$report->lines;
+    my $tag = $data->{tag} || '--';
 
-    if (my $lines = $logger->simple->generate) {
-      print STDOUT $from, ' ', $lines, "\n";
+    if (my $filter = $self->opts->from) {
+      next unless $from =~ /$filter/;
     }
+
+    if (my $filter = $self->opts->tag) {
+      next unless $tag =~ /$filter/;
+    }
+
+    print STDOUT $from, ' ', $tag, ' ', $_, "\n" for @$lines;
   }
 
   $self->okay;
