@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 use Zing::Flow;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # ATTRIBUTES
 
@@ -89,21 +89,21 @@ sub _kill {
 
 method flow() {
   my $step_0 = Zing::Flow->new(
-    name => 'on_reset',
-    code => fun($step, $loop) { $self->on_reset->($self) }
-  );
-  my $step_1 = $step_0->next(Zing::Flow->new(
     name => 'on_register',
     code => fun($step, $loop) { $self->on_register->($self) }
-  ));
-  my $step_2 = $step_1->next(Zing::Flow->new(
+  );
+  my $step_1 = $step_0->next(Zing::Flow->new(
     name => 'on_perform',
     code => fun($step, $loop) { $self->on_perform->($self) }
   ));
-  my $step_3 = $step_2->next(Zing::Flow->new(
+  my $step_2 = $step_1->next(Zing::Flow->new(
     name => 'on_receive',
     code => fun($step, $loop) { $self->on_receive->($self) }
   ));
+  my $step_3 = $step_2->next(Zing::Flow->new(
+    name => 'on_reset',
+    code => fun($step, $loop) { $self->on_reset->($self) }
+  ));
   my $step_4 = $step_3->next(Zing::Flow->new(
     name => 'on_suicide',
     code => fun($step, $loop) { $self->on_suicide->($self) }
@@ -145,10 +145,11 @@ method handle_reset_event() {
   my $process = $self->process;
 
   if ($process->journal && $process->log->count) {
-    $process->journal->send({
-      from => $process->name,
-      data => $process->log->serialize
-    });
+    my $data = {
+      logs => $process->log->serialize,
+      tag => $process->tag,
+    };
+    $process->journal->send({ data => $data, from => $process->name });
   }
 
   $process->log->reset;
