@@ -13,15 +13,15 @@ use Data::Object::ClassHas;
 
 extends 'Zing::PubSub';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # ATTRIBUTES
 
 has 'name' => (
   is => 'ro',
   isa => 'Str',
+  init_arg => undef,
   new => 1,
-  mod => 1,
 );
 
 fun new_name($self) {
