@@ -13,11 +13,11 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Process';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # ATTRIBUTES
 
-has processes => (
+has 'processes' => (
   is => 'ro',
   isa => 'ArrayRef[Process]',
   req => 1
@@ -25,38 +25,54 @@ has processes => (
 
 # METHODS
 
-method perform() {
-  my $position = ($self->{position} ||= 0)++;
-
-  $self->processes->[$position]->exercise;
-
-  delete $self->{position} if ($self->{position} + 1) > @{$self->processes};
-
-  return;
-}
-
 method destroy() {
   $_->destroy for @{$self->processes};
 
+  return $self->next::method;
+}
+
+method execute() {
+  $_->started(time) for @{$self->processes};
+
   $self->next::method;
 
-  return;
+  $_->destroy->stopped(time) for @{$self->processes};
+
+  return $self;
+}
+
+method exercise() {
+  $_->started(time) for @{$self->processes};
+
+  $self->next::method;
+
+  $_->destroy->stopped(time) for @{$self->processes};
+
+  return $self;
+}
+
+method perform() {
+  my $position = ($self->{position} ||= 0)++;
+
+  my $process = $self->processes->[$position];
+
+  $process->loop->exercise($process);
+
+  delete $self->{position} if ($self->{position} + 1) > @{$self->processes};
+
+  return $self;
 }
 
 method shutdown() {
   $_->shutdown for @{$self->processes};
 
-  $self->next::method;
-
-  return;
+  return $self->next::method;
 }
 
 method winddown() {
   $_->winddown for @{$self->processes};
 
-  $self->next::method;
-
-  return;
+  return $self->next::method;
 }
 
 1;
@@ -92,7 +108,7 @@ Multi-Process Assembly Ring
 =head1 DESCRIPTION
 
 This package provides a mechanism for joining two (or more) processes and
-executing them as one in a turn-based fashion.
+executes them as one in a turn-based manner.
 
 =cut
 
@@ -134,7 +150,7 @@ This package implements the following methods:
 
 =head2 destroy
 
-  destroy() : Undef
+  destroy() : Object
 
 The destroy method executes the C<destroy> method of all the processes in the
 list.
@@ -153,7 +169,7 @@ list.
 
 =head2 perform
 
-  perform() : Undef
+  perform() : Any
 
 The perform method executes the event-loop of the next process in the list with
 each call.
@@ -172,7 +188,7 @@ each call.
 
 =head2 shutdown
 
-  shutdown() : Undef
+  shutdown() : Object
 
 The shutdown method executes the C<shutdown> method of all the processes in the
 list.
@@ -191,7 +207,7 @@ list.
 
 =head2 winddown
 
-  winddown() : Undef
+  winddown() : Object
 
 The winddown method executes the C<winddown> method of all the processes in the
 list.
